noop

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package noop provides a backplane that silently discards all messages. Use this for explicit single-node deployments where you want to be clear that no inter-node communication occurs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Backplane

type Backplane struct{}

Backplane is a no-op backplane that discards all messages.

func New

func New() *Backplane

func (*Backplane) Close

func (b *Backplane) Close() error

func (*Backplane) Publish

func (b *Backplane) Publish(_ context.Context, _ backplane.Message) error

func (*Backplane) Subscribe

func (b *Backplane) Subscribe(_ backplane.Handler) (cancel func(), err error)

Jump to