Documentation
¶
Overview ¶
Package memory provides an in-process backplane using Go channels. Intended for testing multi-node scenarios in a single process.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Backplane ¶
type Backplane struct {
// contains filtered or unexported fields
}
Backplane is an in-process backplane that broadcasts messages via Go channels. All subscribers in the same process receive every message.
func NewWithHub ¶
NewWithHub creates a Backplane connected to hub so that published messages are delivered to all other backplanes registered on the same hub.
Click to show internal directories.
Click to hide internal directories.